Nbdler
======


Nbdler is a HTTP/HTTPS downloader programming by Python.



Features
========

-  Resume breakpoint supported.
-  Multi-thread download supported.
-  Multi-url-source download supported.
-  Running in child process mode supported.
-  Download manager pool supported.



License
=======

Apache-2.0

Changelog
=========

1.0.1
~~~~~

-  fixed some bugs.

0.9.9
~~~~~

-  rebuild。
-  multiprocess was supported.

0.0.1
~~~~~

-  Uploaded code。

